#include <stdio.h>
#include <limits.h>

#define INF LONG_MAX
#define MAXV 60 // número máximo de vértices
#define MAXG 200 // grau máximo de cada vértice
#define BRANCO 0
#define PRETO 1


typedef struct { 
	int v; // vértice adjacente
  	int peso; // peso da aresta
} aresta;

typedef struct {
	aresta adj[MAXV][MAXG]; // matriz de adjacências
  	int grau[MAXV]; // grau de saída de cada vértice
  	int nvertices; // número de vértices
  	int narestas; // número de arestas
} grafo;

void prim(grafo *, int);

int main() {
	int x, y, p, i;
	grafo g;
	
	scanf("%d %d", &g.nvertices, &g.narestas);
	for (i = 0; i < g.nvertices; i++) g.grau[i] = 0;
	for (i = 1; i <= g.narestas; i++) {			
		scanf("%d %d %d",&x,&y,&p);
		g.adj[x-1][g.grau[x-1]].v = y-1;
		g.adj[x-1][g.grau[x-1]].peso = p;
		g.grau[x-1]++;
		g.adj[y-1][g.grau[y-1]].v = x-1; 
		g.adj[y-1][g.grau[y-1]].peso = p;
		g.grau[y-1]++;
	}
	prim(&g, 0); // origem é o 1º vértice 
	return 0;	
}

void prim(grafo * g, int origem) {
	int i, j;
	int cor[MAXV]; // o vértice está na árvore?
	int d[MAXV]; // distância do vértice a origem
	int v; // vértice sendo processado
	int w; // candidato ao próximo vértice
	int peso; // peso da aresta
	int dist; // menor distância atual
	int total = 0; // custo total a árvore geradora mínima
	
	for (i = 0; i < g->nvertices; i++) {
		cor[i] = BRANCO;
		d[i] = INF;
	}
	
	d[origem] = 0;
	v = origem;
	while (cor[v] == BRANCO) {
		cor[v] = PRETO;
		for (i = 0; i < g->grau[v]; i++) {
			w = g->adj[v][i].v;
			peso = g->adj[v][i].peso;
			if (d[w] > peso && cor[w] == BRANCO) {
				d[w] = peso;
			}
		}
		v = 0;
		dist = INF;
		for (i = 1; i < g->nvertices; i++) {
			if (cor[i] == BRANCO && dist > d[i]) {
				dist = d[i];
				v = i;
			}
		}
		if (dist != INF) total += dist;
	}
	printf("%d\n", total);	
}

